@@ -5,14 +5,12 @@ __all__ = [
     "time_formater",
     "take_screen_shot",
     "rnd_key",
-    "format_exception",
 ]
 
 import asyncio
 import logging
 import os
 import tempfile
-import traceback
 
 from datetime import timedelta
 from functools import partial, wraps
@@ -62,6 +60,17 @@ def humanbytes(size: Union[float, int]) -> str:
 
 
 def time_formater(value: Union[timedelta, int], precision: int = 0) -> str:
+    """Format Time to Human readable format
+
+    Parameters:
+    ----------
+        - value (`Union[timedelta, int]`): Pass either a `~time.timedelta` or an `int`.
+        - precision (`int`, optional): Decimal Precision. (Defaults to `0`)
+
+    Returns:
+    -------
+        `str`
+    """
     pieces = []
     if isinstance(value, int):
         value = timedelta(seconds=value)
@@ -94,6 +103,17 @@ def rnd_key(length: int = 8) -> str:
 
 
 async def upload_to_telegraph(http: ClientSession, url: str) -> Optional[str]:
+    """Upload Images to Telegra.ph via URL
+
+    Parameters:
+    ----------
+        - http (`ClientSession`): `~aiohttp.ClientSession`.
+        - url (`str`): Http Url.
+
+    Returns:
+    -------
+        `Optional[str]`: Telegra.ph link on success
+    """
     async with http.get(url) as img_url:
         img_bytes = await img_url.read()
     with tempfile.NamedTemporaryFile(delete=False, suffix=".jpg") as temp_img:
@@ -120,7 +140,17 @@ async def upload_to_telegraph(http: ClientSession, url: str) -> Optional[str]:
 
 
 async def take_screen_shot(video_file: str, ttl: int) -> Optional[str]:
-    """Generate Thumbnail from video"""
+    """Generate Thumbnail from video
+
+    Parameters:
+    ----------
+        - video_file (`str`): Video file path.
+        - ttl (`int`): Timestamp.
+
+    Returns:
+    -------
+        `Optional[str]`: On Success
+    """
     file = Path(video_file)
     ss_path = file.parent.joinpath(f"{file.stem}.jpg")
     cmd = ["ffmpeg", "-ss", str(ttl), "-i", video_file, "-vframes", "1", str(ss_path)]
@@ -130,9 +160,3 @@ async def take_screen_shot(video_file: str, ttl: int) -> Optional[str]:
     if stderr := await process.communicate()[1]:
         logger.error(stderr.decode("utf-8", "replace").strip())
     return str(ss_path) if ss_path.is_file() else None
-
-
-def format_exception(exc) -> str:
-    return "".join(
-        traceback.format_exception(etype=type(exc), value=exc, tb=exc.__traceback__)
-    )
